
.. _api:



API Reference
=============

kaiju.cKaiju
------------
The following functions and classes are implemented in C++ and exposed to Python
via `pybind11 <https://github.com/pybind/pybind11>`__.  All cKaiju objects are available in the kaiju namespace, eg the following
two lines are equivalent ::

    from kaiju import Robot
    from kaiju.cKaiju import Robot

.. automodule:: kaiju.cKaiju
   :members:
   :show-inheritance:



